#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const inquirer_1 = __importDefault(require("inquirer"));
const fs = __importStar(require("fs"));
const templateEngine_1 = require("./templateEngine");
const { resolve } = require('path');
async function run() {
    // theses questions will be asked by the cli once you run the `init` command
    const inquiries = [
        {
            type: 'input',
            name: 'name',
            message: 'Project name?',
        },
        {
            type: 'list',
            name: 'framework',
            message: 'Select a framework',
            choices: ['Vue.JS', 'Vanilla'],
            filter(val) {
                return val.toLowerCase().replace('.', '');
            },
        },
        {
            type: 'list',
            name: 'setup',
            message: 'Do you want a basic or batteries-included template',
            choices: ['Basic', 'Batteries-included'],
            filter(val) {
                return val.toLowerCase().replace('-', '');
            },
        },
        {
            type: 'checkbox',
            name: 'services',
            message: 'Which Appwrite services do you intent to use',
            choices: ['Account', 'Database', 'Functions', 'Teams', 'Storage', 'Localization', 'Avatars'],
            filter(val) {
                return val.map((choice) => choice.toLowerCase());
            },
        },
        {
            type: 'input',
            name: 'endpoint',
            message: 'Appwrite endpoint?',
        },
        {
            type: 'input',
            name: 'project',
            message: 'Appwrite project id?',
        },
    ];
    // walk user through questions
    const { name, framework, endpoint, project, setup, services } = await inquirer_1.default.prompt(inquiries).then((answers) => {
        return answers;
    });
    const templateRoot = resolve(__dirname, '..', 'templates');
    const projectDir = `./${name}`;
    const templateDir = resolve(templateRoot, framework, setup);
    const moustacheData = {
        projectName: name,
        appwriteEndpoint: endpoint,
        appwriteProject: project,
    };
    // check if selected directory is empty
    if (!(await isDirEmpty(projectDir))) {
        throw new Error(`${projectDir} is not empty.`);
    }
    console.log(`\nCreating a new project in ${(0, chalk_1.green)(projectDir)}.\n`);
    // copy template into directory
    await (0, templateEngine_1.copy)(projectDir, templateDir, moustacheData);
    // copy appwrite services into directory
    await (0, templateEngine_1.copyAppwrite)(projectDir, services, moustacheData);
    //print success text
    const text = `Your project has been created. Now run:\n${(0, chalk_1.cyan)(`cd ${name}`)}\n${(0, chalk_1.cyan)('npm install')}\n${(0, chalk_1.cyan)('npm run dev')}`;
    console.log(text);
}
function isDirEmpty(dirname) {
    if (fs.existsSync(dirname)) {
        return fs.promises.readdir(dirname).then((files) => {
            return files.length === 0;
        });
    }
    fs.mkdirSync(dirname);
    return true;
}
run();
