"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyAppwrite = exports.copy = void 0;
const fs = __importStar(require("fs/promises"));
const path_1 = require("path");
const handlebars_1 = require("handlebars");
const isUTF8_1 = __importDefault(require("./isUTF8"));
/**
 * formats a text using handlebars
 * @param text the text that should be formatted
 * @param moustaches the moustaches and their data that should be replaced
 */
function format(text, moustaches) {
    const template = (0, handlebars_1.compile)(text.toString(), { noEscape: true });
    return template(moustaches);
}
/*
    Returns a list of all files in a directory
 */
async function goThroughDir(dir) {
    let fileList = [];
    const files = await fs.readdir(dir);
    for (const file of files) {
        const path = (0, path_1.join)(dir, file);
        if ((await fs.stat(path)).isDirectory()) {
            fileList = [...fileList, ...(await goThroughDir(path))];
        }
        else {
            fileList.push(path);
        }
    }
    return fileList;
}
/**
 * Creates the project directory
 * @param filePath the path of the project directory
 */
async function prepareDir(filePath) {
    const target = (0, path_1.dirname)(filePath);
    try {
        await fs.mkdir(target, { recursive: true });
    }
    catch (_a) {
        throw new Error(`Cannot create directory with the path ${target}`);
    }
}
/**
 * Replaces all moustaches in the template and copies it into the project folder
 * @param projectDir the path to the project directory
 * @param templateDir the path to the template directory
 * @param moustaches the moustache data
 */
async function copy(projectDir, templateDir, moustaches) {
    const templateFiles = await goThroughDir(templateDir);
    for (const sourcePath of templateFiles) {
        const relativePath = (0, path_1.relative)(templateDir, sourcePath);
        const targetPath = format((0, path_1.resolve)(projectDir, relativePath), moustaches);
        await prepareDir(targetPath);
        let source = await fs.readFile(sourcePath);
        let target = source;
        if ((0, isUTF8_1.default)(source)) {
            target = Buffer.from(format(source, moustaches));
        }
        await fs.writeFile(targetPath, target, 'utf-8');
    }
}
exports.copy = copy;
/**
 * Copies the selected Appwrite services to the template
 * @param projectDir the selected template
 * @param services the selected Appwrite services
 * @param moustaches the moustache data
 */
async function copyAppwrite(projectDir, services, moustaches) {
    const appwriteDir = (0, path_1.join)(__dirname, '..', projectDir, 'src', 'appwrite');
    const appwriteServicesDir = (0, path_1.join)(__dirname, '..', 'appwrite');
    await fs.mkdir(appwriteDir, { recursive: true });
    // Add interfaces
    let interfaces = [];
    for (let serviceIndex in services) {
        const service = services[serviceIndex];
        interfaces = [...interfaces, `${service}Interfaces`];
    }
    // also add Appwrite base service
    services = [...services, ...interfaces, 'appwrite', 'appwriteInterfaces'];
    for (let serviceIndex in services) {
        const service = services[serviceIndex];
        let source = await fs.readFile((0, path_1.join)(appwriteServicesDir, `${service}.ts`));
        let target = source;
        if ((0, isUTF8_1.default)(source)) {
            target = Buffer.from(format(source, moustaches));
        }
        await fs.writeFile((0, path_1.join)(appwriteDir, `${service}.ts`), target, 'utf-8');
    }
}
exports.copyAppwrite = copyAppwrite;
